!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!                                                                                       !
!                Alternate Surface Fluxes I/O Component of ELCIRC                       !
!                           Version 8 (October 22, 2004)                                !
!                                                                                       !
!                 Center for Coastal and Land-Margin Research                           !
!             Department of Environmental Science and Engineering                       !
!                   OGI School of Science and Engineering,                              !
!                     Oregon Health & Science University                                !
!                       Beaverton, Oregon 97006, USA                                    !
!                                                                                       !
!                   Scientific direction: Antonio Baptista                              !
!                   Code development: Mike A. Zulauf                  			!
!                                                                                       !
!               Copyright 1999-2004 Oregon Health and Science University                !
!                              All Rights Reserved                                      !
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!  
!
!-----------------------------------------------------------------------
! Note: the following global variables (from module global) are used in
!       this code.  This list does not include variables passed in as
!       arguments. . .
!
!       mnp
!       np
!-----------------------------------------------------------------------
!
! Note: this file contains two primary subroutines, get_wind and
!       get_rad.  Their calling convention is defined below.
!
!
!     call get_wind (time, u_air_node, v_air_node, p_air_node, &
!    &               t_air_node, q_air_node)
!
!     scalar
!       time:       model time in seconds
!
!     vectors defined at nodes
!       u_air_node: east/west component of near-surface wind at a
!                   height of 10m, m/s
!       v_air_node: north/south component of near-surface wind at a
!                   height of 10m, m/s
!       p_air_node: surface atmospheric pressure, Pa
!       t_air_node: near-surface air temperature at a height of 2m,
!                   deg K
!       q_air_node: near-surface specific humidity at a height of 2m,
!                   kg/kg
!
!
!     call get_rad (time, shortwave_d, longwave_d)
!
!     scalar
!       time:       model time in seconds
!
!     vectors defined at nodes
!       shortwave_d: downwelling shortwave (solar) radiation at the
!                    surface, W/m^2
!       longwave_d: downwelling longwave (IR) radiation at the
!                    surface, W/m^2
!
! The subroutines as supplied here are primarily meant to serve as
! guidance for users to write their own versions.
!
! Alternatively, they could simply be used to specify specific constant
! (user-supplied) values of these forcing quantities.
!
!-----------------------------------------------------------------------
!
! This subroutine returns the time/space-varying near surface wind
! components, air pressure, air temperature, and specific humidity.
!
      subroutine get_wind (time, u_air_node, v_air_node, p_air_node, &
     &                     t_air_node, q_air_node)

!       implicit none
        use global, only : mnp, np
        implicit real*8(a-h,o-z),integer(i-n)

! define some new names for things in header file
        integer max_nodes
        parameter (max_nodes = mnp)

! input/output variables
        real*8 u_air_node(max_nodes), v_air_node(max_nodes)
        real*8 t_air_node(max_nodes), q_air_node(max_nodes)
        real*8 p_air_node(max_nodes), time

! local variables
        integer num_nodes, i_node

! define the local variables num_nodes
        num_nodes = np

        open(39,file='fort.39')
        rewind(39)
        write(39,*)
        write(39,*) 'enter get_wind'

        write(39,*) 'specifying surface properties'
        do i_node = 1, num_nodes
          u_air_node(i_node) = 0.0d0
          v_air_node(i_node) = 0.0d0
          t_air_node(i_node) = 280.0d0
          q_air_node(i_node) = 8.0d-3
          p_air_node(i_node) = 1.01d5
        enddo

        close(39)

      return
      end
!-----------------------------------------------------------------------
!
! This subroutine returns the time/space-varying downwelling
! shortwave (solar) and longwave (IR) radiative fluxes.
!
! NOTE: solar radiation has been reduced to account for surface albedo.
!
      subroutine get_rad (time, shortwave_d, longwave_d)

!       implicit none
        use global, only : mnp, np
        implicit real*8(a-h,o-z),integer(i-n)

! define some new names for things in header file
        integer max_nodes
        parameter (max_nodes = mnp)

! input/output variables
        real*8 time, longwave_d(max_nodes), shortwave_d(max_nodes)

! local variables
        integer num_nodes, i_node

! define the local variables num_nodes
        num_nodes = np

        open(40,file='fort.40')
        rewind(40)
        write(40,*)
        write(40,*) 'enter get_rad'

        write(40,*) 'specifying shortwave and longwave'
        do i_node = 1, num_nodes
          shortwave_d(i_node) = 100.0d0
          longwave_d(i_node) = 350.0d0
        enddo

        close(40)

      return
      end
!-----------------------------------------------------------------------
